@@ -6,10 +6,10 @@ reorient_volume <- function( volume, Norig ){
   # volume = fill_blanks(brain_finalsurf$get_data(), niter=2)
 
   # Re-order the data according to Norig, map voxels to RAS coord - anatomical
-  order_index = round((Norig %*% c(1,2,3,0))[1:3])
-  volume = aperm(volume, abs(order_index))
-  sub = sprintf(c('%d:1', '1:%d')[(sign(order_index) + 3) / 2], dim(volume))
-  volume = eval(parse(text = sprintf('volume[%s]', paste(sub, collapse = ','))))
+  order_index <- round((Norig %*% c(1,2,3,0))[1:3])
+  volume <- aperm(volume, abs(order_index))
+  sub <- sprintf(c('%d:1', '1:%d')[(sign(order_index) + 3) / 2], dim(volume))
+  volume <- eval(parse(text = sprintf('volume[%s]', paste(sub, collapse = ','))))
 
   volume
 }
